@@ -9,6 +9,8 @@
 
 #include "project.h"
 
+#include <oglappth/base_app.h>
+
 #include <ghemical/engine.h>
 
 #include <ghemical/eng1_qm.h>
@@ -23,7 +25,7 @@ using namespace std;
 
 //#define VERBOSE	// un-comment this to enable debug-messages...
 
-static char * my_num_locale = NULL;	// the temporary locale strings returned by setlocale() will be stored here...
+static char my_num_locale[32] = "C";	// the locale string returned by setlocale() are stored here...
 
 /*################################################################################################*/
 
@@ -31,7 +33,8 @@ bool ReadGPR_OLD(project & prj, istream & file, bool, bool)
 {
 	static const char message[] = "Hmmm. It seems that we are trying to read a VERY OLD version of this file.\nIt's not possible to verify the type and version of the file, so this\noperation may fail. Are you sure you wish to try (Y/N) ??? ";
 	
-	bool result = prj.Question(message);
+	base_app * app = base_app::GetAppB();
+	bool result = app->Question(message);
 	if (!result) return false;
 	
 	vector<atom *> tmp1; i32s tmp2[2]; char tmp3; fGL tmp4[3];
@@ -508,10 +511,10 @@ bool ReadGPR(project & prj, istream & file, bool selected, bool skipheader)
 	const int current_version_number = 111;		// version number multiplied by 100 -> int.
 	char buffer[1024];
 	
-	if (my_num_locale != NULL) cout << "WARNING : my_num_locale != NULL" << endl;	// todo : change into a thread-safe lock???
-	// store the current (numeric) locale into my_num_locale, and switch into "C" numeric locale...
-	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
-	my_num_locale = setlocale(LC_NUMERIC, NULL);
+	// store the current (numeric) locale into my_num_locale,
+	// and switch into the "C" numeric locale...
+	
+	strcpy(my_num_locale, setlocale(LC_NUMERIC, NULL));
 	setlocale(LC_NUMERIC, "C");
 	
 	if (!skipheader)
@@ -543,7 +546,6 @@ bool ReadGPR(project & prj, istream & file, bool selected, bool skipheader)
 			// change the original locale back...
 			// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 			setlocale(LC_NUMERIC, my_num_locale);
-			my_num_locale = NULL;
 			
 			return result;
 		}
@@ -554,7 +556,6 @@ bool ReadGPR(project & prj, istream & file, bool selected, bool skipheader)
 			// change the original locale back...
 			// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 			setlocale(LC_NUMERIC, my_num_locale);
-			my_num_locale = NULL;
 			
 			return result;
 		}
@@ -565,7 +566,6 @@ bool ReadGPR(project & prj, istream & file, bool selected, bool skipheader)
 			// change the original locale back...
 			// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 			setlocale(LC_NUMERIC, my_num_locale);
-			my_num_locale = NULL;
 			
 			return result;
 		}
@@ -573,13 +573,13 @@ bool ReadGPR(project & prj, istream & file, bool selected, bool skipheader)
 		{
 			static const char message[] = "Ooops. It seems that we are trying to read a FUTURE version of this file.\nIt's not sure if we can handle that. Are you sure you wish to try (Y/N) ??? ";
 			
-			bool result = prj.Question(message);
+			base_app * app = base_app::GetAppB();
+			bool result = app->Question(message);
 			if (!result)
 			{
 				// change the original locale back...
 				// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 				setlocale(LC_NUMERIC, my_num_locale);
-				my_num_locale = NULL;
 				
 				return false;
 			}
@@ -654,7 +654,7 @@ if (n1 != ar_vector.size()) cout << "WARNING : atom id number mismatch!!!" << en
 				atom newatom(tmp_element, NULL, prj.GetCRDSetCount());
 				newatom.formal_charge = n3;
 				
-				newatom.flags = n4;
+				newatom.flags = (n4 & 0xFF);	// skip internal...
 				if (selected) newatom.flags |= ATOMFLAG_USER_SELECTED;
 				
 				prj.AddAtom(newatom);
@@ -791,7 +791,6 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 	// change the original locale back...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	setlocale(LC_NUMERIC, my_num_locale);
-	my_num_locale = NULL;
 	
 	// ok, we are ready now!
 	
@@ -804,14 +803,14 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 
 void WriteGPR_v100(project & prj, ostream & file)
 {
-	if (my_num_locale != NULL) cout << "WARNING : my_num_locale != NULL" << endl;	// todo : change into a thread-safe lock???
-	// store the current (numeric) locale into my_num_locale, and switch into "C" numeric locale...
-	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
-	my_num_locale = setlocale(LC_NUMERIC, NULL);
-	setlocale(LC_NUMERIC, "C");
-	
 	const int current_version_number = 100;		// version number multiplied by 100 -> int.
 	
+	// store the current (numeric) locale into my_num_locale,
+	// and switch into the "C" numeric locale...
+	
+	strcpy(my_num_locale, setlocale(LC_NUMERIC, NULL));
+	setlocale(LC_NUMERIC, "C");
+	
 	file << "!Header ";
 	file << prj.GetProjectFileNameExtension() << " ";
 	file << current_version_number << endl;
@@ -905,7 +904,6 @@ void WriteGPR_v100(project & prj, ostream & file)
 	// change the original locale back...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	setlocale(LC_NUMERIC, my_num_locale);
-	my_num_locale = NULL;
 }
 
 /*################################################################################################*/
@@ -919,14 +917,20 @@ void WriteGPR_v100(project & prj, ostream & file)
 
 void WriteGPR(project & prj, ostream & file)
 {
-	if (my_num_locale != NULL) cout << "WARNING : my_num_locale != NULL" << endl;	// todo : change into a thread-safe lock???
-	// store the current (numeric) locale into my_num_locale, and switch into "C" numeric locale...
-	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
-	my_num_locale = setlocale(LC_NUMERIC, NULL);
-	setlocale(LC_NUMERIC, "C");
+prj.Message("\
+PLEASE NOTE : This file format is EXPERIMENTAL!\n\n\
+This file format is NOT compatible with OpenBabel-1.100.2.\n\
+Please use the File/Export to generate OpenBabel-compatible files.");
+//////////////////////////////////////////////////////////////////////
 	
 	const int current_version_number = 111;		// version number multiplied by 100 -> int.
 	
+	// store the current (numeric) locale into my_num_locale,
+	// and switch into the "C" numeric locale...
+	
+	strcpy(my_num_locale, setlocale(LC_NUMERIC, NULL));
+	setlocale(LC_NUMERIC, "C");
+	
 	// write "!Header" section. this is for file-format definition purposes.
 	
 	file << "!Header "; file << "gpr ";
@@ -956,12 +960,18 @@ void WriteGPR(project & prj, ostream & file)
 	while (it1 != prj.GetAtomsEnd())
 	{
 		file << (* it1).index << " ";			// unsigned ints.
-		file << (* it1).el.GetAtomicNumber() << " ";	// signed ints; can be -1 for dummy atoms!!!
-		file.setf(ios::showpos);
-		file << (* it1).formal_charge << " ";		// signed ints.
-		file.unsetf(ios::showpos);
-		file << (* it1).flags << " ";			// unsigned ints; can be large numbers depending on the flags used!
 		
+		file << (* it1).el.GetAtomicNumber() << " ";	// signed ints; can be -1 for dummy atoms!
+		
+		file.setf(ios::showpos);
+		file << (* it1).formal_charge << " ";		// signed ints; SHOW THE SIGN!!!
+		file.unsetf(ios::showpos);
+		
+		i32u tmpflags = (* it1).flags & 0xFF;
+		file << tmpflags << " ";			// unsigned ints; limited on range 0 <-> 255.
+		
+		// what else should we print here ?!?!?!?
+		// what else should we print here ?!?!?!?
 		// what else should we print here ?!?!?!?
 		
 		file << endl;
@@ -1037,7 +1047,6 @@ void WriteGPR(project & prj, ostream & file)
 	// change the original locale back...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	setlocale(LC_NUMERIC, my_num_locale);
-	my_num_locale = NULL;
 }
 
 /*################################################################################################*/
