@@ -37,10 +37,10 @@ using namespace OpenBabel;
 
 namespace OpenBabel
 {
-  extern OBAromaticTyper aromtyper;
-  extern OBAtomTyper atomtyper;
-  extern OBElementTable etab;
-  extern OBTypeTable ettab;
+	extern OBAromaticTyper aromtyper;
+	extern OBAtomTyper atomtyper;
+	extern OBElementTable etab;
+	extern OBTypeTable ettab;
   extern  OBChainsParser   chainsparser;
   extern  OBIsotopeTable   isotab;  
 }
@@ -140,7 +140,6 @@ int file_trans::Import(const char *filename, istream &input, ostream &output)
 int file_trans::Export(const char *filename, istream &input, ostream &output)
 {
   OBConversion conv;
-  OBMol mol; // temporary to allow us to set a title
   OBFormat* inFormat = conv.FindFormat("gpr"); // GHEMICAL
   OBFormat* outFormat = conv.FormatFromExt(filename);
   if (outFormat == NULL)
@@ -149,9 +148,7 @@ int file_trans::Export(const char *filename, istream &input, ostream &output)
   if (! conv.SetInAndOutFormats(inFormat, outFormat) )
     return -1; // cannot read/write these formats
   
-  conv.Read(&mol, &input);
-  mol.SetTitle(filename);
-  conv.Write(&mol, &output);
+  conv.Convert(&input, &output);
   return(0);
 }
 
@@ -226,7 +223,6 @@ int file_trans::Export(const char *filename, unsigned int type,
 {
   OBConversion conv;
   OBFormat* outFormat;
-  OBMol mol; // temp to allow us to set the title
 
   if (type < exports.size())
     outFormat = exports[type].format;
@@ -241,9 +237,7 @@ int file_trans::Export(const char *filename, unsigned int type,
   if (! conv.SetInAndOutFormats(inFormat, outFormat) )
     return -1; // cannot read/write these formats
   
-  conv.Read(&mol, &input);
-  mol.SetTitle(filename);
-  conv.Write(&mol, &output);
+  conv.Convert(&input, &output);
   return(0);
 }
 
